#
# spec file for package phonon-backend-vlc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _phonon_version 4.7.0
Name:           phonon-backend-vlc
Version:        0.10.1
Release:        lp151.2.4
Summary:        Phonon VLC Backend
License:        LGPL-2.1+
Group:          System/GUI/KDE
Url:            http://phonon.kde.org/
Source:         http://download.kde.org/stable/phonon/%{name}/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  kde4-filesystem
BuildRequires:  pkgconfig
BuildRequires:  vlc-devel >= 2.1.0
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(phonon) >= %{_phonon_version}
Requires:       libphonon4 >= %{_phonon_version}
%requires_ge    vlc-noX
Conflicts:      vlc-noX >  %( echo `rpm -q --queryformat '%%{VERSION}' vlc-devel | cut -f -2 -d .`.99)
Provides:       phonon-backend

%description
Phonon is a cross-platform portable Multimedia Support Abstraction,
which allows you to play multiple audio or video formats with the
same quality on all platforms, no matter which underlying
architecture is used.

This is the VLC backend for Phonon.

%prep
%setup -q -n phonon-vlc-%{version}

%build
%cmake_kde4 -d build
%make_jobs

%install
%kde4_makeinstall -C build
%fdupes %{buildroot}

%kde_post_install

%post
%if 0%{?suse_version} >= 1500
%{_libdir}/vlc/vlc-cache-gen %{_libdir}/vlc/plugins
%else
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins
%endif

%files
%defattr(-,root,root)
%doc AUTHORS COPYING.LIB
%dir %{_kde4_servicesdir}/phononbackends
%{_kde4_modulesdir}/plugins/phonon_backend/phonon_vlc.so
%{_kde4_servicesdir}/phononbackends/vlc.desktop

%changelog
* Tue Feb 27 2018 wbauer@tmo.at
- Update to 0.10.1:
  * Fix build with VLC < 3.0
- Drop fix-build-with-vlc2.patch, merged upstream
* Fri Feb 23 2018 wbauer@tmo.at
- Update to 0.10.0:
  * Changes
    + Mimetype support list has been synced with latest VLC
  * Bug Fixes
    + The health of our users is very dear to us, so we've lowered
    the default volume to 75%% to not blow their ears out in the
    event of failure or badly configured frontend software
    + Volume application has been revised and now applies less
    aggressively. This gives PulseAudio a change to apply/restore
    its own default volume.
    + Volume application and correct role forwarding into VLC
    finally make the PulseAudio notification volume apply
    properly to notifications issued via Phonon (VLC 3 only).
  * VLC 3.0 API Pickup
    + New player role is being used to set the output category on a
    PulseAudio level. This fixes a long-standing bug where VLC
    based audio would always be categorized as video.
    + Various deprecation porting.
- Add fix-build-with-vlc2.patch to make it compile with VLC 2.x
* Sun Feb 18 2018 wbauer@tmo.at
- Update to 0.9.1
  * Fix building against older Phonon versions
  * Prevent compilation errors by avoiding preprocessor macros that
    could conflict with VLC's own names (kde#364582)
  * Removed excess warnings from the OS X video widget
  * Introduced a workaround for a double-release bug in the OS X
    video widget introduced in Qt 5.8.0.
- Call vlc-cache-gen on package installation like in
  phonon4qt5-backend-vlc
- Drop fix-build-with-older-phonon.patch, merged upstream
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Fri May 13 2016 wbauer@tmo.at
- Require VLC 2.1.0 at least for building, support for 2.0.x has
  been removed upstream
* Mon May  9 2016 wbauer@tmo.at
- Added fix-build-with-older-phonon.patch to fix building against
  older phonon versions
- Also change required phonon version to 4.7.0, that's the minimum
  supported nowadays
* Sat Apr 23 2016 wbauer@tmo.at
- Remove now unused automoc4 BuildRequires
* Sat Apr 23 2016 wbauer@tmo.at
- Update to 0.9.0
  * No changelog provided
* Mon Apr  4 2016 wbauer@tmo.at
- Conflict with newer VLC versions to prevent problems or even
  crashes (boo#968905)
* Thu Aug 27 2015 sor.alexei@meowr.ru
- Update to 0.8.2:
  * Fix compilation with Qt 5.2+.
- Own /usr/share/kde4/services/phononbackends/ directory as no
  phonon-backend-gstreamer requirement owns it.
- Correct Phonon ABI version.
* Wed Nov  5 2014 hrvoje.senjan@gmail.com
- Update to 0.8.1:
  * Code style improvements.
  * VLC 2.2 compatibility - VLC 2.2 changed the time when
    PulseAudio streams are constructed, rendering the Phonon
    PulseSupport non-functional as it injects stream-dependent
    properties through the environment which needs to happen close
    to stream creation to avoid timing issues. The changed stream
    creation time makes it impossible to provide high-level
    PulseAudio control while also allowing Phonon applications to
    construct multiple AudioOutputs in a very short time frame.
    To allow core functionality from working under these
    circumstances Phonon PulseSupport integration is disabled
    when built against VLC >= 2.2 leading to the following
    known regressions:
    Changing the volume through the PulseAudio stream itself
    is not propagated to Phonon AudioOutputs, meaning the
    application can not reflect volume changes done through
    other applications (e.g. a volume mixer).
    Changing the muteness through the PulseAudio stream is
    not propagated either.
    The PulseAudio media.role property (as well as derived
    properties) is always set to 'video' making all Phonon
    application use the video category for output device
    selection (e.g. as seen in the Phonon KCM).
  * Revised the logic used to come up with an icon name for
    libvlc. If the application has QApplication::windowIcon
    set with an QIcon constructed through QIcon::fromTheme(string)
    the actual icon name will be used.
    Otherwise the lower-case version of
    QCoreApplication::applicationName is used.
  * Setting the libvlc app id is now only dependent on
    QCoreApplication::applicationName being set (previously
    it was also dependent on QCoreApplication::applicationVersion).
    This change was made to accomodate the fact that most
    applications neglect to set a version.
- Bump phonon (Build)Requires to 4.8.2
* Sun Oct 26 2014 vindex17@outlook.it
- Remove version from "phonon-backend" symbol
* Sun Oct 19 2014 hrvoje.senjan@gmail.com
- Update to 0.8.0
  * Version bump
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Update to 0.7.80
  * 0.8 beta: PA interaction improvements, documentation fixes and
    standard bugfixes
- Bump phonon (Build)Requires to 4.7.80
* Fri Jun 20 2014 hrvoje.senjan@gmail.com
- Update to 0.7.2
  * Bugfix release, no changelog provided
* Fri Dec  6 2013 hrvoje.senjan@gmail.com
- Update to 0.7.1:
  * Bugfix release, no changelog provided
- Bump required phonon version to 4.7.1
- Fix Source URL
* Tue Nov 19 2013 hrvoje.senjan@gmail.com
- Relax vlc-noX requirement, for making it easier to install VLC from
  alternative repositories (bnc#851063)
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to official 0.7.0 release
  * No source changes since last update
- Add Source URL
* Mon Nov  4 2013 hrvoje.senjan@gmail.com
- Update to 0.7.0~git20131104
  * Buildsystem fixes since previous snapshot
  * Version bump to 0.7.0
* Sun Oct  6 2013 hrvoje.senjan@gmail.com
- Make phonon-backend-vlc require exact vlc-noX package version
  as vlc version it was compiled against
* Mon Sep 30 2013 hrvoje.senjan@gmail.com
- Update to 0.6.80~git20130930
  * do not release and allocate media_t on audiocd track change
  * do not reset autoplay as applications can set that any time
  * implement attemptautoplay mechanic
* Mon Sep 16 2013 hrvoje.senjan@gmail.com
- Explicitly require current libphonon4 version (4.6.80~git20130915)
* Sun Sep 15 2013 hrvoje.senjan@gmail.com
- Update to 0.6.80~git20130915
  * Snapshot of soon to be released 0.7 version
  * Various improvements, bugfixes, API aditions, documentation fixes
  * Qt5 support
  * Support for vlc's equalizer, when built with vlc >= 2.2
* Sun Apr  7 2013 tittiatcoke@gmail.com
- Initial package for the Phonon VLC backend (0.6.2)
